﻿using System;
using System.Collections.Generic;
using System.Threading;
using Telegram.Bot.Types;
using Telegram.Bot.Types.ReplyMarkups;

public enum StageCalculation
{
    None = 0,
    GetMC = 1,
    GetKMC = 2,
    Get1 = 3,
    Get2 = 4,
    Get3 = 5,
    Get1y = 6,
    Get2y = 7,
    Get3y = 8,
    GetWinTime = 9,
    GetYouTime = 10,
}

public class ExitDate
{
    public int NewRazriadId { get; set; }
    public int NotEnoughSeconds { get; set; }
    public int Reyting { get; set; }
    public int ScorePoint { get; set; }
    public bool IsNullRazriad { get; set; } = false;
    public int IndividualPoints { get; set; }
}

public class Tabl
{
    public int Rating { get; private set; }
    public int[] RazrKoif { get; private set; }
    public Tabl(int raiting, int[] razrKoif)
    {
        Rating = raiting;
        RazrKoif = razrKoif;
    }
}

public static class Data
{
    public static readonly string[][] DEUTIFUL_KEYS = new string[][]
    {
        new string[] {"0"},
        new string[] {"1","2","3"},
        new string[] {"4","5","6"},
        new string[] {"7","8","9"},
        new string[] {"10"}
    };
    public static readonly int[] PointsRazriad = new int[]
{
        100,
        80,
        50,
        25,
        6,
        3,
        2,
        1
};
    public static readonly Tabl[] Tablic = new Tabl[]
    { //                          1    2    3   1ю   2ю
        new Tabl(1000,new int[]{ 136, 151, 169, 0,   0   }),
        new Tabl(850, new int[]{ 133, 148, 166, 0,   0   }),
        new Tabl(750, new int[]{ 130, 145, 163, 0,   0   }),
        new Tabl(650, new int[]{ 127, 142, 160, 0,   0   }),
        new Tabl(500, new int[]{ 124, 139, 157, 192, 0   }),
        new Tabl(425, new int[]{ 121, 136, 154, 188, 0   }),
        new Tabl(375, new int[]{ 118, 133, 151, 184, 215 }),
        new Tabl(325, new int[]{ 115, 130, 148, 180, 210 }),
        new Tabl(250, new int[]{ 112, 127, 145, 176, 205 }),
        new Tabl(211, new int[]{ 109, 124, 142, 172, 200 }),
        new Tabl(185, new int[]{ 106, 121, 139, 168, 195 }),
        new Tabl(159, new int[]{ 103, 118, 136, 164, 190 }),
        new Tabl(120, new int[]{ 100, 115, 133, 160, 185 }),
        new Tabl(102, new int[]{ 0  , 112, 130, 156, 180 }),
        new Tabl(90,  new int[]{ 0  , 109, 127, 152, 175 }),
        new Tabl(78,  new int[]{ 0  , 106, 124, 148, 170 }),
        new Tabl(60,  new int[]{ 0  , 103, 121, 144, 165 }),
        new Tabl(51,  new int[]{ 0  , 100, 118, 140, 160 }),
        new Tabl(45,  new int[]{ 0  , 0  , 115, 136, 155 }),
        new Tabl(39,  new int[]{ 0  , 0  , 112, 132, 150 }),
        new Tabl(30,  new int[]{ 0  , 0  , 109, 128, 145 }),
        new Tabl(27,  new int[]{ 0  , 0  , 106, 124, 140 }),
        new Tabl(25,  new int[]{ 0  , 0  , 103, 120, 135 }),
        new Tabl(23,  new int[]{ 0  , 0  , 100, 116, 130 }),
        new Tabl(20,  new int[]{ 0  , 0  , 0  , 112, 125 }),
        new Tabl(17,  new int[]{ 0  , 0  , 0  , 108, 120 }),
        new Tabl(15,  new int[]{ 0  , 0  , 0  , 104, 116 }),
        new Tabl(13,  new int[]{ 0  , 0  , 0  , 100, 112 }),
        new Tabl(11,  new int[]{ 0  , 0  , 0  , 0  , 108 }),
        new Tabl(10,  new int[]{ 0  , 0  , 0  , 0  , 105 }),
        new Tabl(7,   new int[]{ 0  , 0  , 0  , 0  , 102 }),
        new Tabl(5,   new int[]{ 0  , 0  , 0  , 0  , 100 }),

    };

    public static string GetRazriad(int id)
    {
        switch (id)
        {
            case 0: return "МС";
            case 1: return "КМС";
            case 2: return "I";
            case 3: return "II";
            case 4: return "III";
            case 5: return "Iю";
            case 6: return "IIю";
            case 7: return "IIIю";
            default: return String.Empty;
        }
    }
    
    public static int GetRatingPoints(int[] razriads)
    {
        int ratingPoints = 0;

        for (int i = 0; i < 8; i++)
            ratingPoints += razriads[i] * PointsRazriad[i];
        
        return ratingPoints;
    }
    
    public static IReplyMarkup GetButton(string[][] buttons)
    {
        var keys = new List<List<KeyboardButton>>();

        for (int i = 0; i < buttons.Length; i++)
        {
            var key = new List<KeyboardButton>();

            for (int b = 0; b < buttons[i].Length; b++)
                key.Add(new KeyboardButton { Text = buttons[i][b]});
            
            keys.Add(key);
        }

        return new ReplyKeyboardMarkup { Keyboard = keys };
    }

    public static IReplyMarkup GetButton(params string[] buttons)
    {
        var keys = new List<List<KeyboardButton>>() { new List<KeyboardButton>() };

        foreach (var i in buttons)
            keys[0].Add(new KeyboardButton { Text = i });

        if (buttons.Length == 0)
            return new ReplyKeyboardRemove();

        return new ReplyKeyboardMarkup (keys,true);
    }
}